PaginationMetaData class
Constructors
- PaginationMetaData({String? rooteNode, String totalNode = "total", String currentPageNode = "currentPage", String perPageNode = "perPage"})
Properties
- currentPageNode → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- perPageNode → String
-
final
- rooteNode → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalNode → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited